### Instance

Host
  {$ ctrl.server.host $}

### Fault

Message
  {$ ctrl.server.fault.message $}
Code
  {$ ctrl.server.fault.code $}
Details
  {$ ctrl.server.fault.details $}
Created
  {$ ctrl.server.fault.created $}

### Specs

Flavor Name
  {$ ctrl.flavor.name $}
Flavor ID
  {$ ctrl.flavor.id $}
RAM
  {$ ctrl.flavor.ram | mb $}
VCPUs
  {$ ctrl.flavor.vcpus $}
Disk
  {$ ctrl.flavor.disk | gb $}

### IP Addresses

{$ network $}
  {$ ctrl.getAddresses(ip_list) $}

### Security Groups

{$ group.name $}
  - {$ ctrl.ruleToString(rule) $}
  - No rules defined

### Metadata

{$ ctrl.resourceType.label(prop) $}
  {$ value $}

### Volumes Attached

Attached To
  {$ volume.name || volume.id $} / {$ volume.device $}

No Volumes Attached